Init
====

command : linchpin init

This command initialises the PinFile and directory structure to facilitate linchpin rise and linchpin drop commands.

.. note:: If the PinFile/directories already exists in the current working directory it prompts user with yes/no option to override the existing file structure and PinFile.

Options:
  --path PATH  path for initialisation
  --help       Help

=========
Examples:
=========

+------------------------+---------------------------------------------------------+
| Usage                  | Action                                                  |
+========================+=========================================================+
| linchpin init          |  initialises the directory structure for rise & drop    |
+------------------------+---------------------------------------------------------+
